Struct Group

pub struct Group {
Show 19 fields pub creation_time: DateTime<Utc>, pub custom_icon_uuid: Option<CustomIconUuid>, pub def_auto_type_sequence: String, pub enable_auto_type: Option<bool>, pub enable_searching: Option<bool>, pub entries: Vec<EntryUuid>, pub expires: bool, pub expiry_time: DateTime<Utc>, pub groups: Vec<GroupUuid>, pub icon: Icon, pub is_expanded: bool, pub last_accessed: DateTime<Utc>, pub last_modified: DateTime<Utc>, pub last_top_visible_entry: EntryUuid, pub location_changed: DateTime<Utc>, pub name: String, pub notes: String, pub usage_count: i32, pub uuid: GroupUuid,
}
A group in the database.

Fields

creation_time: DateTime<Utc>

The date and time this group was created.

custom_icon_uuid: Option<CustomIconUuid>

The identifier of this group’s custom icon if any.

def_auto_type_sequence: String

Default auto-type sequence.

enable_auto_type: Option<bool>

Whether auto-type is enabled.

enable_searching: Option<bool>

Whether searching is enabled.

entries: Vec<EntryUuid>

Vector with entry identifiers that belong to this group.

expires: bool

Whether this group expires.

expiry_time: DateTime<Utc>

The date and time this group will expire if expires is true.

groups: Vec<GroupUuid>

Vector with group identifiers that are subgroups of this group.

icon: Icon

This group’s icon.

is_expanded: bool

Whether this group is expanded.

last_accessed: DateTime<Utc>

The date and time this group was last accessed.

last_modified: DateTime<Utc>

The date and time this group was last modified.

last_top_visible_entry: EntryUuid

The identifier of the last top visible entry.

location_changed: DateTime<Utc>

The date and time the location of this group was changed.

name: String

The name of this group.

notes: String

The notes of this group.

usage_count: i32

The usage count of this group.

uuid: GroupUuid

The identifier of this group.

Implementations

Source

impl Group

pub fn new<S: Into<String>>(name: S) -> Group

Create a new group.

Examples
use kpdb::Group;

let group = Group::new("Websites");