pub struct Database {Show 41 fields
pub comment: Option<Comment>,
pub composite_key: CompositeKey,
pub compression: Compression,
pub db_type: DbType,
pub master_cipher: MasterCipher,
pub stream_cipher: StreamCipher,
pub transform_rounds: TransformRounds,
pub version: Version,
pub binaries: BinariesMap,
pub color: Option<Color>,
pub custom_data: CustomDataMap,
pub custom_icons: CustomIconsMap,
pub def_username: String,
pub def_username_changed: DateTime<Utc>,
pub description: String,
pub description_changed: DateTime<Utc>,
pub entries: EntriesMap,
pub entry_templates_group_changed: DateTime<Utc>,
pub entry_templates_group_uuid: GroupUuid,
pub generator: String,
pub group_uuid: Option<GroupUuid>,
pub groups: GroupsMap,
pub history: HistoryMap,
pub history_max_items: i32,
pub history_max_size: i32,
pub last_selected_group: GroupUuid,
pub last_top_visible_group: GroupUuid,
pub maintenance_history_days: i32,
pub master_key_change_force: i32,
pub master_key_change_rec: i32,
pub master_key_changed: DateTime<Utc>,
pub name: String,
pub name_changed: DateTime<Utc>,
pub protect_notes: bool,
pub protect_password: bool,
pub protect_title: bool,
pub protect_url: bool,
pub protect_username: bool,
pub recycle_bin_changed: DateTime<Utc>,
pub recycle_bin_enabled: bool,
pub recycle_bin_uuid: GroupUuid,
}Expand description
The KeePass database.
Fields
comment: Option<Comment>Content of the comment header.
composite_key: CompositeKeyComposite key.
compression: CompressionCompression algorithm.
db_type: DbTypeType of the database.
master_cipher: MasterCipherMaster encryption algorithm.
stream_cipher: StreamCipherStream encryption algorithm (e.g. passwords).
transform_rounds: TransformRoundsNumber of times the composite key must be transformed.
version: VersionThe database version.
binaries: BinariesMapMap with binary data.
color: Option<Color>Optional color.
custom_data: CustomDataMapMap with custom data.
custom_icons: CustomIconsMapMap with custom icons.
def_username: StringDefault username for new entries.
def_username_changed: DateTime<Utc>The date and time the default username was changed.
description: StringDescription of this database.
description_changed: DateTime<Utc>The date and time the description was changed.
entries: EntriesMapMap with entries.
entry_templates_group_changed: DateTime<Utc>The date and time the entry templates group was changed.
entry_templates_group_uuid: GroupUuidThe identifier of the group containing entry templates.
generator: StringName of the generator.
group_uuid: Option<GroupUuid>The identifier of the root group.
groups: GroupsMapMap with groups.
history: HistoryMapMap with history entries.
history_max_items: i32Maximum number of history items.
history_max_size: i32Maximum size of the history data.
last_selected_group: GroupUuidThe identifier of the last selected group.
last_top_visible_group: GroupUuidThe identifier of the last top visible group.
maintenance_history_days: i32Number of days until history entries are being deleted.
master_key_change_force: i32master_key_change_rec: i32master_key_changed: DateTime<Utc>The date and time the master key was changed.
name: StringName of this database.
name_changed: DateTime<Utc>The date and time the name was changed.
protect_notes: boolWhether notes must be protected.
protect_password: boolWhether passwords must be protected.
protect_title: boolWhether titles must be protected.
protect_url: boolWhether URL’s must be protected.
protect_username: boolWhether usernames must be protected.
recycle_bin_changed: DateTime<Utc>The date and time the recycle bin was changed.
recycle_bin_enabled: boolWhether the recycle bin is enabled.
recycle_bin_uuid: GroupUuidThe identifier of the recycle bin.
Implementations
Sourceimpl Database
impl Database
Sourcepub fn new(key: &CompositeKey) -> Database
pub fn new(key: &CompositeKey) -> Database
Create a new database.
Examples
use kpdb::{CompositeKey, Database};
let key = CompositeKey::from_password("password");
let db = Database::new(&key);Sourcepub fn open<R: Read>(reader: &mut R, key: &CompositeKey) -> Result<Database>
pub fn open<R: Read>(reader: &mut R, key: &CompositeKey) -> Result<Database>
Attempts to open an existing database.
Examples
use kpdb::{CompositeKey, Database};
use std::fs::File;
let mut file = try!(File::open("passwords.kdbx"));
let key = CompositeKey::from_password("password");
let db = try!(Database::open(&mut file, &key));Sourcepub fn save<W: Write>(&self, writer: &mut W) -> Result<()>
pub fn save<W: Write>(&self, writer: &mut W) -> Result<()>
Attempts to save the database.
Examples
use kpdb::{CompositeKey, Database};
use std::fs::File;
let key = CompositeKey::from_password("password");
let db = Database::new(&key);
let mut file = try!(File::create("new.kdbx"));
try!(db.save(&mut file));